Revision: 46084
http://sourceforge.net/p/vice-emu/code/46084
Author: gpz
Date: 2026-04-26 13:52:46 +0000 (Sun, 26 Apr 2026)
Log Message:
-----------
use unique name for the snapshot module :)
Modified Paths:
--------------
trunk/vice/src/c64/cart/turtlegraphics.c
Modified: trunk/vice/src/c64/cart/turtlegraphics.c
===================================================================
--- trunk/vice/src/c64/cart/turtlegraphics.c 2026-04-19 12:51:15 UTC (rev 46083)
+++ trunk/vice/src/c64/cart/turtlegraphics.c 2026-04-26 13:52:46 UTC (rev 46084)
@@ -180,7 +180,7 @@
/* ---------------------------------------------------------------------*/
/* CARTSTB snapshot module format:
type | name | version | description
--------------------------------------
@@ -187,11 +187,13 @@
BYTE | bank | 0.1 | current bank
BYTE | active | 0.1 | cartridge active flag
ARRAY | ROML | 0.0+ | 16384 BYTES of ROML data
+
+ Note: renamed from "CARTSTB" in 0.2
*/
-static const char snap_module_name[] = "CARTSTB";
+static const char snap_module_name[] = "CARTTURTLEGFX";
#define SNAP_MAJOR 0
-#define SNAP_MINOR 1
+#define SNAP_MINOR 2
int turtlegraphics_snapshot_write_module(snapshot_t *s)
{
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
@@ -180,7 +180,7 @@
/* ---------------------------------------------------------------------*/
-/* CARTSTB snapshot module format:
+/* CARTTURTLEGFX 0.2 snapshot module format:
type | name | version | description
|